@@ -5,13 +5,17 @@ from harpoon.tasks import available_tasks
 from harpoon.imager import Imager
 
 from option_merge import MergedOptions
+import logging
 import yaml
 import os
 
+log = logging.getLogger("harpoon.executor")
+
 class Task(object):
-    def __init__(self, func, args=None, kwargs=None, description=None):
+    def __init__(self, func, args=None, kwargs=None, description=None, label="Harpoon"):
         self.func = func
         self.args = args
+        self.label = label
         self.kwargs = kwargs
         self.description = description
 
@@ -28,13 +32,15 @@ class Task(object):
         return self.func(harpoon, *args, **opts)
 
 class Harpoon(object):
-    def __init__(self, configuration_file, docker_context, silent_build=False, interactive=True):
+    def __init__(self, configuration_file, docker_context, silent_build=False, interactive=True, logging_handler=None):
         self.interactive = interactive
         self.docker_context = docker_context
+        self.logging_handler = logging_handler
 
         self.configuration = self.collect_configuration(configuration_file)
         self.configuration_folder = os.path.dirname(os.path.abspath(configuration_file))
         self.imager = Imager(self.configuration, docker_context, interactive=self.interactive, silent_build=silent_build)
+        self.setup_logging_theme()
 
     def start(self, task, extra=None, keep_replaced=False, no_intervention=False, env=None, ports=None, **kwargs):
         """Do the harpooning"""
@@ -99,7 +105,45 @@ class Harpoon(object):
                         except BadYaml as error:
                             errors.append(error)
 
-        return MergedOptions.using(configuration, *collected)
+        return MergedOptions.using(self.home_dir_configuration(), configuration, *collected)
+
+    def setup_logging_theme(self):
+        """Setup a logging theme"""
+        if "term_colors" not in self.configuration:
+            return
+
+        if not getattr(self, "logging_handler", None):
+            log.warning("Told to set term_colors but don't have a logging_handler to change")
+            return
+
+        colors = self.configuration.get("term_colors")
+        if not colors:
+            return
+
+        if colors not in ("light", "dark"):
+            log.warning("Told to set colors to a theme we don't have\tgot=%s\thave=[light, dark]", colors)
+            return
+
+        # Haven't put much effort into actually working out more than just the message colour
+        if colors == "light":
+            self.logging_handler._column_color['%(message)s'][logging.INFO] = ('cyan', None, False)
+        else:
+            self.logging_handler._column_color['%(message)s'][logging.INFO] = ('blue', None, False)
+
+    def home_dir_configuration(self):
+        """Return a dictionary from ~/.harpoon.yml"""
+        location = os.path.expanduser("~/.harpoon.yml")
+        if not os.path.exists(location):
+            return {}
+
+        result = self.read_yaml(location)
+        if not result:
+            result = {}
+        if not isinstance(result, dict):
+            raise BadYaml("Expected yaml file to declare a dictionary", location=location, got=type(result))
+
+        result["__mtime__"] = self.get_committime_or_mtime(location)
+        return result
 
     def read_yaml(self, filepath):
         """Read in a yaml file"""
@@ -146,14 +190,21 @@ class Harpoon(object):
 
         for key, val in found.items():
             args = None
+            label = "Project"
             kwargs = None
             task_path = "{0}.{1}".format(path, key)
             description = ""
             if isinstance(val, dict) or isinstance(val, MergedOptions):
+                label = val.get("label", label)
                 description = val.get("description", "")
-                if "spec" not in val:
-                    raise BadTask("Dictionary task needs to specify spec", found=val.keys())
-                val = val.get("spec")
+
+                if "options" in val and "spec" in val:
+                    raise BadTask("Dictionary task must specify spec or options, not both", found=val.keys())
+
+                if "options" in val:
+                    val = ["run_task", [], val["options"]]
+                else:
+                    val = val.get("spec", "run_task")
 
             if isinstance(val, basestring):
                 task_name = val
@@ -180,7 +231,7 @@ class Harpoon(object):
 
                 if image not in kwargs and image is not None:
                     kwargs['image'] = image
-                tasks[key] = Task(available_tasks[task_name], args, kwargs, description=description)
+                tasks[key] = Task(available_tasks[task_name], args, kwargs, description=description, label=label)
 
         if errors:
             raise BadTask(path=path, _errors=errors)
