@@ -1,6 +1,8 @@
 from harpoon.errors import BadOption
 
 from docker.errors import APIError as DockerAPIError
+import itertools
+import operator
 import logging
 import os
 
@@ -113,11 +115,18 @@ def run_task(harpoon, image=None, command=None, bash=None, env=None, volumes=Non
 def list_tasks(harpoon, **kwargs):
     """List the available_tasks"""
     print("Available tasks to choose from are:")
-    print("---")
-    for key, task in sorted(harpoon.find_tasks().items()):
-        print("{0}: {1}".format(key, task.description or ""))
-    print("---")
     print("Use the --task option to choose one")
+    print("")
+    keygetter = lambda item: item[1].label
+    tasks = sorted(harpoon.find_tasks().items(), key=keygetter)
+    for label, items in itertools.groupby(tasks, keygetter):
+        print("--- {0}".format(label))
+        print("----{0}".format("-" * len(label)))
+        sorted_tasks = sorted(list(items), key=lambda item: len(item[0]))
+        max_length = max(len(name) for name, _ in sorted_tasks)
+        for key, task in sorted_tasks:
+            print("\t{0}{1} :-: {2}".format(" " * (max_length-len(key)), key, task.description or ""))
+        print("")
 
 @a_task
 def delete_untagged(harpoon, **kwargs):
